︠31efe4e9-5039-42ff-a574-25d042a4ffc0i︠
%html
<p>The import commands load the libraries we will need to call certain functions.</p>

︡19775429-37ae-47a9-ad85-d6084ad403fb︡{"html": "<p>The import commands load the libraries we will need to call certain functions.</p>"}︡
︠76a69dd5-13ff-4325-a495-c40fda04caa3︠
import numpy as np
import matplotlib.pyplot as plt
import scipy.linalg as la
︡7b8e46a4-6dc9-4268-b77f-8cb9f326384b︡︡
︠3a01ea92-04d9-47d3-9bf0-1ce1d4b02b27i︠
%html
<p>Define some useful constants</p>

︡3befe83f-66c8-464a-8e3d-277516e884da︡{"html": "<p>Define some useful constants</p>"}︡
︠231017c8-4fd6-402c-9dd8-0e466b01724d︠
mu = [1.0,0.0,0.0] # magnetic dipole moment of bar magnet
kmag = 1e-7
︡aae3ad56-f10e-4050-9b3c-739ee666a3fb︡︡
︠e1eb1d2e-15d3-482d-92bb-8413eb567a7bi︠
%html
<p>Define a function for computing the field of a particle with a magnetic dipole</p>

︡bfd3a00f-5450-44fe-83fc-a693bb3df0cc︡{"html": "<p>Define a function for computing the field of a particle with a magnetic dipole</p>"}︡
︠d1b027e0-0388-4573-8cdb-ff8374640496︠
def Bdipole(source,obsloc):
    r = np.subtract(source,obsloc)
    return kmag*(3*np.dot(mu,r/la.norm(r))*r/la.norm(r) - mu)/(np.dot(r,r))^(3/2)
︡b15810b6-d966-4a27-abed-3335b51405bc︡︡
︠23a6afbe-a91f-4b16-8f9b-7077a9f2395ei︠
%html
<p>Define a function for computing the field of a magnetic monopole</p>

︡4a478339-e635-4b15-9f80-44ccd998284a︡{"html": "<p>Define a function for computing the field of a magnetic monopole</p>"}︡
︠1947a817-df45-4270-9376-17e90f2b0d62︠
def Bmono(source,obsloc):
    r = np.subtract(source,obsloc)
    return 100*kmag*r/la.norm(r)/(np.dot(r,r))
︡b02e101a-0c41-4ac5-9c37-05c523308c37︡︡
︠1b80a41b-e623-43d6-a82c-1f26eab86c97i︠
%html
<p>We will compute the flux at points along a radius of the loop, separated by a distance dR, and use this to compute the integrated flux over the entire loop</p>

︡946ea75e-7ff0-4ce9-8948-d1dfce661dae︡{"html": "<p>We will compute the flux at points along a radius of the loop, separated by a distance dR, and use this to compute the integrated flux over the entire loop</p>"}︡
︠026de53a-8d3b-47df-8bd7-1bea56d5197d︠
center=[0.2,0,0]   #Center of the loop
Rdisk = 0.3        #Radius of the loop
Bsurface = [] 
dR = 0.05*Rdisk     #Determines how many points to sample to compute the flux
for y in np.arange(0,Rdisk,dR):
    pos=[center[0], y, 0]
    Bsurface.append(pos)   #Add point to list of points
︡04d244c8-7845-425d-b9ec-bad7f74ff645︡︡
︠3c33eab8-66b4-4b12-807a-7127738b4881i︠
%html
<p>Below is the main loop over time. &nbsp;At each time step, we move the particle forward according to its speed, compute the fields at each point along the radius of the loop, and from this we compute the flux. &nbsp;By keeping track of the flux from the previous time step in variables called oldflux, we may approximate the flux derivative as the ratio of the change in flux and the change in time.</p>

︡7d980d07-f56f-43fb-b11b-a93bd099fcf4︡{"html": "<p>Below is the main loop over time. &nbsp;At each time step, we move the particle forward according to its speed, compute the fields at each point along the radius of the loop, and from this we compute the flux. &nbsp;By keeping track of the flux from the previous time step in variables called oldflux, we may approximate the flux derivative as the ratio of the change in flux and the change in time.</p>"}︡
︠2b54c9e9-8671-4e43-b66b-f97f42fd5bc8︠
dt=0.01  #Time step in seconds
xhat = [1,0,0]  #unit vector for the loop surface
vx=0.1  #Speed of the particle in meters per second
dfluxddt=[]   #lists for the flux derivatives
dfluxmdt=[]
magnetpos=[0.0,0.0,0.0]  #initial position of the particle
time=np.arange(0.0,4.0,dt)  #create a list of time steps
fluxd=0.0
fluxm=0.0
oldfluxd=fluxd
oldfluxm=fluxm
for t in time:
    magnetpos[0] += vx*dt  #Advance the particle
    oldfluxd=fluxd   #Store the previous flux values
    oldfluxm=fluxm
    fluxd=0.0
    fluxm=0.0
    #Perform the integral over loop enclosed area
    for arr in Bsurface:    #For each point along the loop radius
        Bd = Bdipole(magnetpos, arr)  #Compute the dipole field
        Bm = Bmono(magnetpos,arr)     #Compute the monopole field
        fluxd+=np.dot(Bd,xhat)*2.0*np.pi*abs(arr[1])*dR  #compute the dipole flux
        fluxm+=np.dot(Bm,xhat)*2.0*np.pi*abs(arr[1])*dR  #Compute the monopole flux
    dfluxddt.append((fluxd-oldfluxd)/dt)  #Compute the flux derivatives
    dfluxmdt.append((fluxm-oldfluxm)/dt)
︡2f3a8904-d0f9-4069-8d0d-22fa89f7b877︡︡
︠fd81ce34-890f-4538-a416-c7cad211f185i︠
%html
<p>The following commands make a nice plot of our results.</p>

︡2d9ed976-cc82-46bd-ae8d-eb5a91e08a5f︡{"html": "<p>The following commands make a nice plot of our results.</p>"}︡
︠b54805d1-6919-4afc-8401-8df3b03653e2︠
plt.cla()
plt.clf()
plt.figure()
#[1:-1] means plot the second to last points.  Since we have computed derivatives as differences, the first point has not been computed correctly.
plt.plot(time[1:-1],dfluxddt[1:-1],'k', time[1:-1], dfluxmdt[1:-1],'k--')
plt.xlabel('Time(s)')
plt.ylabel('Current (arbitrary units)')
plt.title('Current induced in a conducting loop due to a particle')
plt.yticks([])
plt.legend(['Magnetic Dipole','Magnetic Monopole'])
ax=plt.gca()
plt.savefig('blah')
plt.show()
︡69d3d858-c223-4353-b127-fbf6aab81e63︡︡
